==> zio-aws-iot1clickdevices_2.13-5.17.104.10-sources.jar: zio/aws/iot1clickdevices/model/UpdateDeviceStateRequest.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.iot1clickdevices.model.primitives.{__boolean, __string}
import scala.jdk.CollectionConverters._
final case class UpdateDeviceStateRequest(
    deviceId: __string,
    enabled: Option[__boolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.UpdateDeviceStateRequest = {
    import UpdateDeviceStateRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.UpdateDeviceStateRequest
      .builder()
      .deviceId(__string.unwrap(deviceId): java.lang.String)
      .optionallyWith(
        enabled.map(value => __boolean.unwrap(value): java.lang.Boolean)
      )(_.enabled)
      .build()
  }
  def asReadOnly
      : zio.aws.iot1clickdevices.model.UpdateDeviceStateRequest.ReadOnly =
    zio.aws.iot1clickdevices.model.UpdateDeviceStateRequest
      .wrap(buildAwsValue())
}
object UpdateDeviceStateRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.UpdateDeviceStateRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickdevices.model.UpdateDeviceStateRequest =
      zio.aws.iot1clickdevices.model
        .UpdateDeviceStateRequest(deviceId, enabled.map(value => value))
    def deviceId: __string
    def enabled: Option[__boolean]
    def getDeviceId: ZIO[Any, Nothing, __string] = ZIO.succeed(deviceId)
    def getEnabled: ZIO[Any, AwsError, __boolean] =
      AwsError.unwrapOptionField("enabled", enabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.UpdateDeviceStateRequest
  ) extends zio.aws.iot1clickdevices.model.UpdateDeviceStateRequest.ReadOnly {
    override val deviceId: __string =
      zio.aws.iot1clickdevices.model.primitives.__string(impl.deviceId())
    override val enabled: Option[__boolean] = scala
      .Option(impl.enabled())
      .map(value => zio.aws.iot1clickdevices.model.primitives.__boolean(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.UpdateDeviceStateRequest
  ): zio.aws.iot1clickdevices.model.UpdateDeviceStateRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iot1clickdevices_2.13-5.17.153.2-sources.jar: zio/aws/iot1clickdevices/model/UpdateDeviceStateRequest.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.iot1clickdevices.model.primitives.{__boolean, __string}
import scala.jdk.CollectionConverters._
final case class UpdateDeviceStateRequest(
    deviceId: __string,
    enabled: Option[__boolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.UpdateDeviceStateRequest = {
    import UpdateDeviceStateRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.UpdateDeviceStateRequest
      .builder()
      .deviceId(deviceId: java.lang.String)
      .optionallyWith(enabled.map(value => value: java.lang.Boolean))(_.enabled)
      .build()
  }
  def asReadOnly
      : zio.aws.iot1clickdevices.model.UpdateDeviceStateRequest.ReadOnly =
    zio.aws.iot1clickdevices.model.UpdateDeviceStateRequest
      .wrap(buildAwsValue())
}
object UpdateDeviceStateRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.UpdateDeviceStateRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickdevices.model.UpdateDeviceStateRequest =
      zio.aws.iot1clickdevices.model
        .UpdateDeviceStateRequest(deviceId, enabled.map(value => value))
    def deviceId: __string
    def enabled: Option[__boolean]
    def getDeviceId: ZIO[Any, Nothing, __string] = ZIO.succeed(deviceId)
    def getEnabled: ZIO[Any, AwsError, __boolean] =
      AwsError.unwrapOptionField("enabled", enabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.UpdateDeviceStateRequest
  ) extends zio.aws.iot1clickdevices.model.UpdateDeviceStateRequest.ReadOnly {
    override val deviceId: __string = impl.deviceId(): __string
    override val enabled: Option[__boolean] =
      scala.Option(impl.enabled()).map(value => value: __boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.UpdateDeviceStateRequest
  ): zio.aws.iot1clickdevices.model.UpdateDeviceStateRequest.ReadOnly =
    new Wrapper(impl)
}
